@@ -48,6 +48,22 @@ def test_saveImage_multipage(tmpdir):
     assert expected_filenames == [p.name for p in sorted(tmpdir.glob("*.png"))]
 
 
+def test_saveImage_mp4(tmpdir):
+    from drawbot_skia import ffmpeg
+    ffmpeg.FFMPEG_PATH = ffmpeg.getPyFFmpegPath()  # Force ffmpeg from pyffmpeg
+    tmpdir = pathlib.Path(tmpdir)
+    db = Drawing()
+    namespace = makeDrawbotNamespace(db)
+    runScriptSource(multipageSource, "<string>", namespace)
+    assert [] == sorted(tmpdir.glob("*.png"))
+    db.saveImage(tmpdir / "test.mp4")
+    db.saveImage(tmpdir / "test2.mp4", codec="mpeg4")
+    expected_filenames = ['test.mp4', 'test2.mp4']
+    paths = sorted(tmpdir.glob("*.mp4"))
+    assert paths[0].stat().st_size < paths[1].stat().st_size
+    assert expected_filenames == [p.name for p in paths]
+
+
 def test_noFont(tmpdir):
     db = Drawing()
     # Ensure we don't get an error when font is not set
